==> qt6-translations_6.2.4.orig.tar.xz: qttranslations-everywhere-src-6.2.4/translations/qtwebsockets_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>QQmlWebSocket</name>
    <message>
        <source>Messages can only be sent when the socket is open.</source>
        <translation>Els missatges només es poden enviar quan el sòcol està obert.</translation>
    </message>
    <message>
        <source>QQmlWebSocket is not ready.</source>
        <translation>El «QQmlWebSocket» no està llest.</translation>
    </message>
</context>
<context>
    <name>QQmlWebSocketServer</name>
    <message>
        <source>QQmlWebSocketServer is not ready.</source>
        <translation>El «QQmlWebSocketServer» no està llest.</translation>
    </message>
</context>
<context>
    <name>QWebSocket</name>
    <message>
        <source>Connection closed</source>
        <translation>Connexió tancada</translation>
    </message>
    <message>
        <source>Invalid URL.</source>
        <translation>URL no vàlid.</translation>
    </message>
    <message>
        <source>Invalid resource name.</source>
        <translation>El nom del recurs no és vàlid.</translation>
    </message>
    <message>
        <source>SSL Sockets are not supported on this platform.</source>
        <translation>Els sòcols SSL no estan admesos en aquesta plataforma.</translation>
    </message>
    <message>
        <source>Out of memory.</source>
        <translation>S&apos;ha esgotat la memòria.</translation>
    </message>
    <message>
        <source>Unsupported WebSocket scheme: %1</source>
        <translation>Esquema «WebSocket» no admès: %1</translation>
    </message>
    <message>
        <source>Error writing bytes to socket: %1.</source>
        <translation>Error en escriure els bytes al sòcol: %1.</translation>
    </message>
    <message>
        <source>Bytes written %1 != %2.</source>
        <translation>Bytes escrits %1 != %2.</translation>
    </message>
    <message>
        <source>Invalid statusline in response: %1.</source>
        <translation>Línia d&apos;estat no vàlida a la resposta: %1.</translation>
    </message>
    <message>
        <source>QWebSocketPrivate::processHandshake: Connection closed while reading header.</source>
        <translation>QWebSocketPrivate::processHandshake: La connexió s&apos;ha tancat mentre es llegia la capçalera.</translation>
    </message>
    <message>
        <source>Accept-Key received from server %1 does not match the client key %2.</source>
        <translation>La clau d&apos;acceptació rebuda del servidor %1 no coincideix amb la clau del client %2.</translation>
    </message>
    <message>
        <source>QWebSocketPrivate::processHandshake: Invalid statusline in response: %1.</source>
        <translation>QWebSocketPrivate::processHandshake: Línia d&apos;estat no vàlida a la resposta: %1.</translation>
    </message>
    <message>
        <source>Handshake: Server requests a version that we don&apos;t support: %1.</source>
        <translation>Handshake: El servidor sol·licita una versió que no s&apos;admet: %1.</translation>
    </message>
    <message>
        <source>QWebSocketPrivate::processHandshake: Unknown error condition encountered. Aborting connection.</source>
        <translation>QWebSocketPrivate::processHandshake: S&apos;ha trobat una condició d&apos;error desconeguda. S&apos;està interrompent la connexió.</translation>
    </message>
    <message>
        <source>QWebSocketPrivate::processHandshake: Unhandled http status code: %1 (%2).</source>
        <translation>QWebSocketPrivate::processHandshake: Codi d’estat HTTP sense gestionar: %1 (%2).</translation>
    </message>
    <message>
        <source>The resource name contains newlines. Possible attack detected.</source>
        <translation>El nom del recurs conté salts de línia. S&apos;ha detectat un possible atac.</translation>
    </message>
    <message>
        <source>The hostname contains newlines. Possible attack detected.</source>
        <translation>El nom de l&apos;amfitrió conté salts de línia. S&apos;ha detectat un possible atac.</translation>
    </message>
    <message>
        <source>The origin contains newlines. Possible attack detected.</source>
        <translation>L&apos;origen conté salts de línia. S&apos;ha detectat un possible atac.</translation>
    </message>
    <message>
        <source>The extensions attribute contains newlines. Possible attack detected.</source>
        <translation>Les extensions contenen salts de línia. S&apos;ha detectat un possible atac.</translation>
    </message>
    <message>
        <source>The protocols attribute contains newlines. Possible attack detected.</source>
        <translation>L&apos;atribut dels protocols conté salts de línia. S&apos;ha detectat un possible atac.</translation>
    </message>
</context>
<context>
    <name>QWebSocketDataProcessor</name>
    <message>
        <source>Received Continuation frame, while there is nothing to continue.</source>
        <translation>S&apos;ha rebut un marc de continuació, encara que no hi havia res a continuar.</translation>
    </message>
    <message>
        <source>All data frames after the initial data frame must have opcode 0 (continuation).</source>
        <translation>Tots els marcs de dades després del marc de dades inicial hauran de tenir el codi d&apos;opció 0 (continuació).</translation>
    </message>
    <message>
        <source>Received message is too big.</source>
        <translation>El missatge rebut és massa gran.</translation>
    </message>
    <message>
        <source>Invalid UTF-8 code encountered.</source>
        <translation>S&apos;ha trobat un codi UTF-8 no vàlid.</translation>
    </message>
    <message>
        <source>Payload of close frame is too small.</source>
        <translation>La càrrega útil del marc de tancament és massa petita.</translation>
    </message>
    <message>
        <source>Invalid close code %1 detected.</source>
        <translation>S&apos;ha detectat el codi de tancament %1 no vàlid.</translation>
    </message>
    <message>
        <source>Invalid opcode detected: %1</source>
        <translation>S&apos;ha detectat un codi d&apos;operació no vàlid: %1</translation>
    </message>
</context>
<context>
    <name>QWebSocketFrame</name>
    <message>
        <source>Timeout when reading data from socket.</source>
        <translation>Temps d&apos;espera quan es llegeixen dades des del sòcol.</translation>
    </message>
    <message>
        <source>Error occurred while reading from the network: %1</source>
        <translation>S&apos;ha produït un error mentre es llegia de la xarxa: %1</translation>
    </message>
    <message>
        <source>Lengths smaller than 126 must be expressed as one byte.</source>
        <translation>Les longituds menors que 126 s&apos;han d’expressar com un byte.</translation>
    </message>
    <message>
        <source>Something went wrong during reading from the network.</source>
        <translation>Quelcom ha anat malament mentre es llegia de la xarxa.</translation>
    </message>
    <message>
        <source>Highest bit of payload length is not 0.</source>
        <translation>El bit més alt de la longitud de càrrega útil no és 0.</translation>
    </message>
    <message>
        <source>Lengths smaller than 65536 (2^16) must be expressed as 2 bytes.</source>
        <translation>Les longituds inferiors a 65536 (2^16) s&apos;han d&apos;expressar en 2 bytes.</translation>
    </message>
    <message>
        <source>Error while reading from the network: %1.</source>
        <translation>Error mentre es llegia de la xarxa: %1.</translation>
    </message>
    <message>
        <source>Maximum framesize exceeded.</source>
        <translation>S&apos;ha excedit la mida màxima del marc.</translation>
    </message>
    <message>
        <source>Some serious error occurred while reading from the network.</source>
        <translation>S&apos;ha produït un error greu mentre es llegia de la xarxa.</translation>
    </message>
    <message>
        <source>Rsv field is non-zero</source>
        <translation>El camp RSV és diferent de zero</translation>
    </message>
    <message>
        <source>Used reserved opcode</source>
        <translation>S&apos;ha emprat un codi d&apos;operació reservat</translation>
    </message>
    <message>
        <source>Control frame is larger than 125 bytes</source>
        <translation>El marc de control és major que 125 bytes</translation>
    </message>
    <message>
        <source>Control frames cannot be fragmented</source>
        <translation>Els marcs de control no es poden fragmentar</translation>
    </message>
</context>
<context>
    <name>QWebSocketHandshakeResponse</name>
    <message>
        <source>Access forbidden.</source>
        <translation>Accés prohibit.</translation>
    </message>
    <message>
        <source>Unsupported version requested.</source>
        <translation>S&apos;ha sol·licitat una versió no admesa.</translation>
    </message>
    <message>
        <source>One of the headers contains a newline. Possible attack detected.</source>
        <translation>Una de les capçaleres conté un salt de línia. S&apos;ha detectat un possible atac.</translation>
    </message>
    <message>
        <source>Bad handshake request received.</source>
        <translation>S&apos;ha rebut una sol·licitud dolenta de negociació.</translation>
    </message>
</context>
<context>
    <name>QWebSocketServer</name>
    <message>
        <source>Server closed.</source>
        <translation>Servidor tancat.</translation>
    </message>
    <message>
        <source>Too many pending connections.</source>
        <translation>Hi ha massa connexions pendents.</translation>
    </message>
    <message>
        <source>Upgrade to WebSocket failed.</source>
        <translation>Ha fallat l&apos;actualització al «WebSocket».</translation>
    </message>
    <message>
        <source>Invalid response received.</source>
        <translation>S&apos;ha rebut una resposta no vàlida.</translation>
    </message>
</context>
</TS>

==> qt6-translations_6.9.2.orig.tar.xz: qttranslations-everywhere-src-6.9.2/translations/qtwebsockets_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca_ES">
<context>
    <name>QQmlWebSocket</name>
    <message>
        <source>Messages can only be sent when the socket is open.</source>
        <translation>Els missatges només es poden enviar quan el sòcol està obert.</translation>
    </message>
    <message>
        <source>QQmlWebSocket is not ready.</source>
        <translation>El «QQmlWebSocket» no està llest.</translation>
    </message>
</context>
<context>
    <name>QQmlWebSocketServer</name>
    <message>
        <source>QQmlWebSocketServer is not ready.</source>
        <translation>El «QQmlWebSocketServer» no està llest.</translation>
    </message>
</context>
<context>
    <name>QWebSocket</name>
    <message>
        <source>Connection closed</source>
        <translation>Connexió tancada</translation>
    </message>
    <message>
        <source>Invalid URL.</source>
        <translation>URL no vàlid.</translation>
    </message>
    <message>
        <source>Invalid resource name.</source>
        <translation>El nom del recurs no és vàlid.</translation>
    </message>
    <message>
        <source>SSL Sockets are not supported on this platform.</source>
        <translation>Els sòcols SSL no estan admesos en aquesta plataforma.</translation>
    </message>
    <message>
        <source>Out of memory.</source>
        <translation>S&apos;ha esgotat la memòria.</translation>
    </message>
    <message>
        <source>Unsupported WebSocket scheme: %1</source>
        <translation>Esquema «WebSocket» no admès: %1</translation>
    </message>
    <message>
        <source>Error writing bytes to socket: %1.</source>
        <translation>Error en escriure els bytes al sòcol: %1.</translation>
    </message>
    <message>
        <source>Bytes written %1 != %2.</source>
        <translation>Bytes escrits %1 != %2.</translation>
    </message>
    <message>
        <source>QWebSocketPrivate::processHandshake: Unsupported WWW-Authenticate challenge encountered.</source>
        <extracomment>&apos;WWW-Authenticate&apos; is the HTTP header.</extracomment>
        <translation>QWebSocketPrivate::processHandshake: S&apos;ha trobat un repte WWW-Autenticate no admès.</translation>
    </message>
    <message>
        <source>QWebSocketPrivate::processHandshake: Unsupported WWW-Authenticate challenges encountered.</source>
        <translation>QWebSocketPrivate::processHandshake: S&apos;han trobat reptes WWW-Autenticate no admesos.</translation>
    </message>
    <message>
        <source>Header is too large</source>
        <translation>La capçalera és massa gran</translation>
    </message>
    <message>
        <source>Read handshake request header failed</source>
        <translation>Ha fallat la lectura de la capçalera de conformitat de la connexió</translation>
    </message>
    <message>
        <source>Read handshake request status failed</source>
        <translation>Ha fallat l&apos;estat de la sol·licitud de conformitat de la connexió</translation>
    </message>
    <message>
        <source>Parsing handshake request header failed</source>
        <translation>Ha fallat l&apos;anàlisi de la capçalera de conformitat de la connexió</translation>
    </message>
    <message>
        <source>WebSocket server has chosen protocol %1 which has not been requested</source>
        <translation>El servidor WebSocket ha triat el protocol %1 que no s&apos;havia sol·licitat</translation>
    </message>
    <message>
        <source>Invalid parameter encountered during protocol upgrade: %1</source>
        <translation>S&apos;ha trobat un paràmetre no vàlid durant l&apos;actualització del protocol: %1</translation>
    </message>
    <message>
        <source>Invalid parameter(s) presented during protocol upgrade: %1</source>
        <translation type="vanished">Paràmetre/s no vàlid/s (s) presentat/s durant l&apos;actualització del protocol: %1</translation>
    </message>
    <message>
        <source>Invalid statusline in response: %1.</source>
        <translation type="vanished">Línia d&apos;estat no vàlida a la resposta: %1.</translation>
    </message>
    <message>
        <source>QWebSocketPrivate::processHandshake: Connection closed while reading header.</source>
        <translation type="vanished">QWebSocketPrivate::processHandshake: La connexió s&apos;ha tancat mentre es llegia la capçalera.</translation>
    </message>
    <message>
        <source>Accept-Key received from server %1 does not match the client key %2.</source>
        <translation>La clau d&apos;acceptació rebuda del servidor %1 no coincideix amb la clau del client %2.</translation>
    </message>
    <message>
        <source>QWebSocketPrivate::processHandshake: Invalid statusline in response: %1.</source>
        <translation type="vanished">QWebSocketPrivate::processHandshake: Línia d&apos;estat no vàlida a la resposta: %1.</translation>
    </message>
    <message>
        <source>Handshake: Server requests a version that we don&apos;t support: %1.</source>
        <translation>Handshake: El servidor sol·licita una versió que no s&apos;admet: %1.</translation>
    </message>
    <message>
        <source>QWebSocketPrivate::processHandshake: Unknown error condition encountered. Aborting connection.</source>
        <translation>QWebSocketPrivate::processHandshake: S&apos;ha trobat una condició desconeguda d&apos;error. S&apos;està interrompent la connexió.</translation>
    </message>
    <message>
        <source>QWebSocket::processHandshake: Host requires authentication</source>
        <translation>QWebSocket::processHandshake: El servidor requereix autenticació</translation>
    </message>
    <message>
        <source>QWebSocketPrivate::processHandshake: Unhandled http status code: %1 (%2).</source>
        <translation>QWebSocketPrivate::processHandshake: Codi d&apos;estat HTTP sense gestionar: %1 (%2).</translation>
    </message>
    <message>
        <source>The resource name contains newlines. Possible attack detected.</source>
        <translation>El nom del recurs conté salts de línia. S&apos;ha detectat un possible atac.</translation>
    </message>
    <message>
        <source>The hostname contains newlines. Possible attack detected.</source>
        <translation>El nom de l&apos;amfitrió conté salts de línia. S&apos;ha detectat un possible atac.</translation>
    </message>
    <message>
        <source>The origin contains newlines. Possible attack detected.</source>
        <translation>L&apos;origen conté salts de línia. S&apos;ha detectat un possible atac.</translation>
    </message>
    <message>
        <source>The extensions attribute contains newlines. Possible attack detected.</source>
        <translation>Les extensions contenen salts de línia. S&apos;ha detectat un possible atac.</translation>
    </message>
    <message>
        <source>The protocols attribute contains newlines. Possible attack detected.</source>
        <translation type="vanished">L&apos;atribut dels protocols conté salts de línia. S&apos;ha detectat un possible atac.</translation>
    </message>
    <message>
        <source>Connection refused</source>
        <translation>S&apos;ha rebutjat la connexió</translation>
    </message>
</context>
<context>
    <name>QWebSocketDataProcessor</name>
    <message>
        <source>Received Continuation frame, while there is nothing to continue.</source>
        <translation>S&apos;ha rebut un marc de continuació, encara que no hi havia res a continuar.</translation>
    </message>
    <message>
        <source>All data frames after the initial data frame must have opcode 0 (continuation).</source>
        <translation>Tots els marcs de dades després del marc de dades inicial hauran de tenir el codi d&apos;opció 0 (continuació).</translation>
    </message>
    <message>
        <source>Received message is too big.</source>
        <translation>El missatge rebut és massa gran.</translation>
    </message>
    <message>
        <source>Invalid UTF-8 code encountered.</source>
        <translation>S&apos;ha trobat un codi UTF-8 no vàlid.</translation>
    </message>
    <message>
        <source>Payload of close frame is too small.</source>
        <translation>La càrrega útil del marc de tancament és massa petita.</translation>
    </message>
    <message>
        <source>Invalid close code %1 detected.</source>
        <translation>S&apos;ha detectat el codi de tancament %1 no vàlid.</translation>
    </message>
    <message>
        <source>Invalid opcode detected: %1</source>
        <translation>S&apos;ha detectat un codi d&apos;operació no vàlid: %1</translation>
    </message>
    <message>
        <source>Timeout when reading data from socket.</source>
        <translation>Temps excedit en llegir dades des del sòcol.</translation>
    </message>
</context>
<context>
    <name>QWebSocketFrame</name>
    <message>
        <source>Timeout when reading data from socket.</source>
        <translation type="vanished">Temps d&apos;espera quan es llegeixen dades des del sòcol.</translation>
    </message>
    <message>
        <source>Waiting for more data from socket.</source>
        <translation>En espera de més dades des del sòcol.</translation>
    </message>
    <message>
        <source>Error occurred while reading header from the network: %1</source>
        <translation>S&apos;ha produït un error mentre es llegia la capçalera des de la xarxa: %1</translation>
    </message>
    <message>
        <source>Error occurred while reading from the network: %1</source>
        <translation>S&apos;ha produït un error mentre es llegia de la xarxa: %1</translation>
    </message>
    <message>
        <source>Lengths smaller than 126 must be expressed as one byte.</source>
        <translation>Les longituds menors que 126 s&apos;han d&apos;expressar com un byte.</translation>
    </message>
    <message>
        <source>Something went wrong during reading from the network.</source>
        <translation>Quelcom ha anat malament mentre es llegia de la xarxa.</translation>
    </message>
    <message>
        <source>Highest bit of payload length is not 0.</source>
        <translation>El bit més alt de la longitud de càrrega útil no és 0.</translation>
    </message>
    <message>
        <source>Lengths smaller than 65536 (2^16) must be expressed as 2 bytes.</source>
        <translation>Les longituds inferiors a 65536 (2^16) s&apos;han d&apos;expressar en 2 bytes.</translation>
    </message>
    <message>
        <source>Error while reading from the network: %1.</source>
        <translation>Error mentre es llegia de la xarxa: %1.</translation>
    </message>
    <message>
        <source>Maximum framesize exceeded.</source>
        <translation>S&apos;ha excedit la mida màxima del marc.</translation>
    </message>
    <message>
        <source>Some serious error occurred while reading from the network.</source>
        <translation>S&apos;ha produït un error greu mentre es llegia de la xarxa.</translation>
    </message>
    <message>
        <source>Rsv field is non-zero</source>
        <translation>El camp RSV és diferent de zero</translation>
    </message>
    <message>
        <source>Used reserved opcode</source>
        <translation>S&apos;ha emprat un codi d&apos;operació reservat</translation>
    </message>
    <message>
        <source>Control frame is larger than 125 bytes</source>
        <translation>El marc de control és major que 125 bytes</translation>
    </message>
    <message>
        <source>Control frames cannot be fragmented</source>
        <translation>Els marcs de control no es poden fragmentar</translation>
    </message>
</context>
<context>
    <name>QWebSocketHandshakeResponse</name>
    <message>
        <source>Access forbidden.</source>
        <translation>Accés prohibit.</translation>
    </message>
    <message>
        <source>Unsupported version requested.</source>
        <translation>S&apos;ha sol·licitat una versió no admesa.</translation>
    </message>
    <message>
        <source>One of the headers contains a newline. Possible attack detected.</source>
        <translation>Una de les capçaleres conté un salt de línia. S&apos;ha detectat un possible atac.</translation>
    </message>
    <message>
        <source>Bad handshake request received.</source>
        <translation>S&apos;ha rebut una sol·licitud dolenta de negociació.</translation>
    </message>
</context>
<context>
    <name>QWebSocketServer</name>
    <message>
        <source>Server closed.</source>
        <translation>Servidor tancat.</translation>
    </message>
    <message>
        <source>Header is too large.</source>
        <translation>La capçalera és massa gran.</translation>
    </message>
    <message>
        <source>Too many pending connections.</source>
        <translation>Hi ha massa connexions pendents.</translation>
    </message>
    <message>
        <source>Read handshake request header failed.</source>
        <translation>Ha fallat la lectura de la capçalera de conformitat de la connexió.</translation>
    </message>
    <message>
        <source>Upgrade to WebSocket failed.</source>
        <translation>Ha fallat l&apos;actualització al «WebSocket».</translation>
    </message>
    <message>
        <source>Invalid response received.</source>
        <translation>S&apos;ha rebut una resposta no vàlida.</translation>
    </message>
</context>
</TS>
